@@ -12,9 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Package for an indexable circular array data structure."""
+"""### Circular Array
 
-__version__ = "3.4.0"
+Package for an indexable circular array data structure.
+"""
+__version__ = "3.4.1"
 __author__ = "Geoffrey R. Scheller"
 __copyright__ = "Copyright (c) 2023-2024 Geoffrey R. Scheller"
 __license__ = "Apache License 2.0"
